@@ -7,9 +7,6 @@ use strict;
 use Carp;
 use MIME::Base64;
 
-our $VERSION = '0.03';
-our $DEBUG => 0;
-
 # we still call it Lu2 even though it's actually no longer squared ;-)
 
 sub _lu2 {
@@ -46,3 +43,22 @@ sub _lu2_constant {
 
 1;
 __END__
+
+=pod
+
+=head1 NAME
+
+Digest::OMAC2 - OMAC 2 implementation
+
+=head1 SYNOPSIS
+
+	use Digest::OMAC2;
+
+	my $d = Digest::OMAC2->new( $key, $cipher );
+
+=head1 DESCRIPTION
+
+OMAC 2 is a variant of the CMAC/OMAC 1 algorithm. The initialization routines
+are slightly different. OMAC2 actually precedes OMAC1, so
+L<Digest::CMAC>/L<Digest::OMAC1> is the reccomended version. Supposedly OMAC1
+was more rigorously analyzed.
